==> 0.0.13.tar.gz: lib/datapicker.dart <==
import 'package:wowit/model.dart';

class DataPicker {
  static String getDataPicker(List<KeyValue> data, int id,
      {String defaultValue}) {
    for (int i = 0; i < data.length; i++) {
      try {
        if (data[i].valueMember == id) {
          return data[i].displayMember;
        }
      } catch (e) {
        print('getDataPicker ex:' + e.toString());
      }
    }

    return defaultValue;
  }

  static List<KeyValue> getDataPickerDanhMuc() {
    return [
      new KeyValue(-1, 1, "Căn hộ/Chung cư"),
      new KeyValue(-1, 2, "Đất"),
      new KeyValue(-1, 3, "Nhà ở"),
      new KeyValue(-1, 4, "Văn phòng"),
      new KeyValue(-1, 5, "Mặt bằng kinh doanh"),
      new KeyValue(-1, 6, "Phòng trọ"),
      new KeyValue(-1, 7, "Khu công nghiệp"),
      new KeyValue(-1, 8, "Dự án"),
      new KeyValue(-1, 9, "Công ty")
    ];
  }

  static List<KeyValue> getDataPickerNhomBDS() {
    return [new KeyValue(-1, 1, "Âu Mỹ"), new KeyValue(-1, 2, "Châu Á ")];
  }

  static List<KeyValue> getDataPickerHinhThuc() {
    return [
      new KeyValue(-1, 1, "Cần bán"),
      new KeyValue(-1, 2, "Cần mua"),
      new KeyValue(-1, 3, "Nhà ở"),
      new KeyValue(-1, 4, "Cho Thuê")
    ];
  }

  static List<KeyValue> getDataPickerSoPhongNgu() {
    return [
      new KeyValue(-1, 1, "1-2 pn"),
      new KeyValue(-1, 2, "2-3 pn"),
      new KeyValue(-1, 2, "5-7 pn"),
      new KeyValue(-1, 3, "7-9 pn"),
      new KeyValue(-1, 4, "trên 10 pn")
    ];
  }

  static List<KeyValue> getDataPickerNganSach() {
    return [
      new KeyValue(-1, 1, "1 tỷ"),
      new KeyValue(-1, 2, "2 tỷ"),
      new KeyValue(-1, 3, "5 tỷ"),
      new KeyValue(-1, 4, "10 tỷ")
    ];
  }

  static List<KeyValue> getDataPickerNganSachThue() {
    return [
      new KeyValue(-1, 1, "Dưới 5 tr"),
      new KeyValue(-1, 2, "5-7tr"),
      new KeyValue(-1, 3, "7-10tr"),
      new KeyValue(-1, 4, "10-15tr"),
      new KeyValue(-1, 5, "15-20tr"),
      new KeyValue(-1, 6, "20-30tr"),
      new KeyValue(-1, 7, "30-50tr"),
      new KeyValue(-1, 8, "Trên 50tr")
    ];
  }

  static List<KeyValue> getDataPickerNganSachMua() {
    return [
      new KeyValue(-1, 1, "Dưới 2 tỉ"),
      new KeyValue(-1, 2, "2-3 tỷ"),
      new KeyValue(-1, 3, "3-5 tỷ"),
      new KeyValue(-1, 4, "5-7 tỷ"),
      new KeyValue(-1, 5, "7-10 tỷ"),
      new KeyValue(-1, 6, "10-20 tỷ"),
      new KeyValue(-1, 7, "20-30 tỷ"),
      new KeyValue(-1, 8, "trên 30 tỷ")
    ];
  }

  static List<KeyValue> getDataPickerLoaiHinhNhaO() {
    return [
      new KeyValue(-1, 1, "Nhà mặt phố, mặt tiền"),
      new KeyValue(-1, 2, "Nhà ngỏ,hẻm"),
      new KeyValue(-1, 3, "Nhà phố liền kề")
    ];
  }

  static List<KeyValue> getDataPickerTrangThai() {
    return [
      new KeyValue(-1, 1, "Nháp"),
      new KeyValue(-1, 2, "Đang xử lý"),
      new KeyValue(-1, 3, "Đã duyệt"),
      new KeyValue(-1, 4, "Từ chối")
    ];
  }

  static List<KeyValue> getDataPickerDienTich() {
    return [
      new KeyValue(-1, 1, "<=30m2"),
      new KeyValue(-1, 2, "30-50m2"),
      new KeyValue(-1, 3, "50-80m2"),
      new KeyValue(-1, 3, "80-100m2"),
      new KeyValue(-1, 3, "100-150m2"),
      new KeyValue(-1, 3, "150-200m2"),
      new KeyValue(-1, 3, "200-250m2"),
      new KeyValue(-1, 3, "250-350m2"),
      new KeyValue(-1, 3, "350-500m2"),
      new KeyValue(-1, 4, ">=500m2")
    ];
  }

  static List<KeyValue> getDataPickerHuongCuaChinh() {
    return [
      new KeyValue(-1, 1, "Đông"),
      new KeyValue(-1, 2, "Tây"),
      new KeyValue(-1, 3, "Nam"),
      new KeyValue(-1, 4, "Bắc"),
      new KeyValue(-1, 5, "Đông Bắc"),
      new KeyValue(-1, 6, "Đông Nam"),
      new KeyValue(-1, 7, "Tây Bắc"),
      new KeyValue(-1, 8, "Tây Nam")
    ];
  }

  static List<KeyValue> getDataPickerGioiTinh() {
    return [
      new KeyValue(-1, 1, "Nam"),
      new KeyValue(-1, 0, "Nữ"),
      new KeyValue(-1, 2, "Khác")
    ];
  }

  static List<KeyValue> getDataPickerYesNo() {
    return [new KeyValue(-1, 1, "Có"), new KeyValue(-1, 2, "Không")];
  }

  static List<KeyValue> getDataPickerTinhTrangHonNhan() {
    return [
      new KeyValue(-1, 1, "Độc thân"),
      new KeyValue(-1, 2, "Đã có gia đình")
    ];
  }

  static List<KeyValue> getDataPickerDangBoi() {
    return [new KeyValue(-1, 1, "Cá nhân"), new KeyValue(-1, 2, "Môi giới")];
  }

  static List<KeyValue> getDataPickerLoaiTaiLieu() {
    return [
      new KeyValue(-1, 1, "Pdf"),
      new KeyValue(-1, 2, "Excel"),
      new KeyValue(-1, 3, "WebView"),
      new KeyValue(-1, 4, "Youtube")
    ];
  }

  static List<KeyValue> getDataPickerNhomKhachHang() {
    return [
      new KeyValue(-1, 1, "Bình thường"),
      new KeyValue(-1, 2, "Đã giới thiệu"),
      new KeyValue(-1, 3, "Tìm năng"),
      new KeyValue(-1, 4, "Vip")
    ];
  }

  static List<KeyValue> getDataPickerLoaiLabel() {
    return [
      new KeyValue(-1, 1, "lb"),
      new KeyValue(-1, 2, "data"),
      new KeyValue(-1, 3, "tf"),
      new KeyValue(-1, 4, "btn")
    ];
  }

  static List<KeyValue> getDataPickerTypeQuestionHelper() {
    return [new KeyValue(-1, 1, "Video"), new KeyValue(-1, 2, "Văn bản")];
  }

  static List<KeyValue> getDataPickerNgonNguGoc() {
    return [new KeyValue(-1, 1, "vi")];
  }

  static List<KeyValue> getDataPickerDapAnCauHoi() {
    return [
      new KeyValue(-1, 1, "A"),
      new KeyValue(-1, 2, "B"),
      new KeyValue(-1, 3, "C"),
      new KeyValue(-1, 4, "D")
    ];
  }

  static List<KeyValue> getDataPickerLoaiNoiDungHocOnline() {
    return [
      new KeyValue(-1, 1, "Video"),
      new KeyValue(-1, 2, "Câu hỏi trắc nghiệm")
    ];
  }

  static List<KeyValue> getDataPickerTienDoDuAn() {
    return [
      new KeyValue(-1, 1, "Đang xây dựng"),
      new KeyValue(-1, 2, "Sắp mở bán"),
      new KeyValue(-1, 3, "Đã hoàn thành")
    ];
  }

  static List<KeyValue> getDataPickerTrangThaiThamDinh() {
    return [
      new KeyValue(-1, 1, "Chưa thẩm định"),
      new KeyValue(-1, 2, "Đang thẩm định"),
      new KeyValue(-1, 3, "Đã thẩm định")
    ];
  }

  static List<KeyValue> getDataPickerTrangThaiSangNhuong() {
    return [
      new KeyValue(-1, 1, "Sang nhượng"),
      new KeyValue(-1, 2, "Cho thuê"),
      new KeyValue(-1, 3, "Bán")
    ];
  }

  static List<KeyValue> getDataPickerGiayToPhapLy() {
    return [new KeyValue(-1, 1, "Đã có sổ"), new KeyValue(-1, 2, "Chưa có sổ")];
  }

  static List<KeyValue> getDataPickerNhomThongBao() {
    return [
      new KeyValue(-1, 1, "Tài khoản"),
      new KeyValue(-1, 2, "Bất động sản"),
      new KeyValue(-1, 3, "Lời mời kết bạn")
    ];
  }

  static List<KeyValue> getDataPickerLevel() {
    return [
      new KeyValue(-1, 1, "Thành viên"),
      new KeyValue(-1, 2, "Đồng"),
      new KeyValue(-1, 3, "Bạc"),
      new KeyValue(-1, 4, "Vàng"),
      new KeyValue(-1, 5, "Bạch kim")
    ];
  }

  static List<KeyValue> getDataPickerTrangThaiHoatDong() {
    return [
      new KeyValue(-1, 1, "Đang hoạt động"),
      new KeyValue(-1, 2, "Tạm đóng cửa"),
      new KeyValue(-1, 3, "Ngưng hoạt động")
    ];
  }

  static List<KeyValue> getDataPickerDanhMucShop() {
    return [
      new KeyValue(-1, 1, "Spa"),
      new KeyValue(-1, 2, "Hair"),
      new KeyValue(-1, 3, "Nail"),
      new KeyValue(-1, 4, "Eyelash"),
      new KeyValue(-1, 5, "Makeup"),
      new KeyValue(-1, 6, "Phun xăm"),
      new KeyValue(-1, 7, "Stylish")
    ];
  }
}

==> 0.0.19.tar.gz: lib/datapicker.dart <==
import 'package:wowit/model.dart';

class DataPicker {
  static String getDataPicker(List<KeyValue> data, int id,
      {String defaultValue}) {
    for (int i = 0; i < data.length; i++) {
      try {
        if (data[i].valueMember == id) {
          return data[i].displayMember;
        }
      } catch (e) {
        print('getDataPicker ex:' + e.toString());
      }
    }

    return defaultValue;
  }
//căn hộ, biệt thự, nhà phố, tòa nhà, đất nền, khu công nghiệp, dự án
  static List<KeyValue> getDataPickerDanhMuc() {
    return [
      // new KeyValue(-1, 1, "Căn hộ/Chung cư"),
      // new KeyValue(-1, 2, "Đất"),
      // new KeyValue(-1, 3, "Nhà ở"),
      // new KeyValue(-1, 4, "Văn phòng"),
      // new KeyValue(-1, 5, "Mặt bằng kinh doanh"),
      // new KeyValue(-1, 6, "Phòng trọ"),
      // new KeyValue(-1, 7, "Khu công nghiệp"),
      // new KeyValue(-1, 8, "Dự án"),
      // new KeyValue(-1, 9, "Công ty")
      new KeyValue(-1, 1, "Căn hộ")
      ,new KeyValue(-1, 2, "Biệt thự")
      ,new KeyValue(-1, 3, "Nhà phố")
      ,new KeyValue(-1, 4, "Tòa nhà")
      ,new KeyValue(-1, 5, "Đất nền")
      ,new KeyValue(-1, 6, "Khu công nghiệp")
      ,new KeyValue(-1, 7, "Dự án")

    ];
  }

  static List<KeyValue> getDataPickerNhomBDS() {
    return [new KeyValue(-1, 1, "Âu Mỹ"), new KeyValue(-1, 2, "Châu Á ")];
  }

  static List<KeyValue> getDataPickerHinhThuc() {
    return [
      new KeyValue(-1, 1, "Cần bán"),
      new KeyValue(-1, 2, "Cần mua"),
      new KeyValue(-1, 3, "Nhà ở"),
      new KeyValue(-1, 4, "Cho Thuê")
    ];
  }

  static List<KeyValue> getDataPickerSoPhongNgu() {
    return [
      new KeyValue(-1, 1, "1-2 pn"),
      new KeyValue(-1, 2, "2-3 pn"),
      new KeyValue(-1, 2, "5-7 pn"),
      new KeyValue(-1, 3, "7-9 pn"),
      new KeyValue(-1, 4, "trên 10 pn")
    ];
  }

  static List<KeyValue> getDataPickerNganSach() {
    return [
      new KeyValue(-1, 1, "1 tỷ"),
      new KeyValue(-1, 2, "2 tỷ"),
      new KeyValue(-1, 3, "5 tỷ"),
      new KeyValue(-1, 4, "10 tỷ")
    ];
  }

  static List<KeyValue> getDataPickerNganSachThue() {
    return [
      new KeyValue(-1, 1, "Dưới 5 tr"),
      new KeyValue(-1, 2, "5-7tr"),
      new KeyValue(-1, 3, "7-10tr"),
      new KeyValue(-1, 4, "10-15tr"),
      new KeyValue(-1, 5, "15-20tr"),
      new KeyValue(-1, 6, "20-30tr"),
      new KeyValue(-1, 7, "30-50tr"),
      new KeyValue(-1, 8, "Trên 50tr")
    ];
  }

  static List<KeyValue> getDataPickerNganSachMua() {
    return [
      new KeyValue(-1, 1, "Dưới 2 tỉ"),
      new KeyValue(-1, 2, "2-3 tỷ"),
      new KeyValue(-1, 3, "3-5 tỷ"),
      new KeyValue(-1, 4, "5-7 tỷ"),
      new KeyValue(-1, 5, "7-10 tỷ"),
      new KeyValue(-1, 6, "10-20 tỷ"),
      new KeyValue(-1, 7, "20-30 tỷ"),
      new KeyValue(-1, 8, "trên 30 tỷ")
    ];
  }

  static List<KeyValue> getDataPickerLoaiHinhNhaO() {
    return [
      new KeyValue(-1, 1, "Nhà mặt phố, mặt tiền"),
      new KeyValue(-1, 2, "Nhà ngỏ,hẻm"),
      new KeyValue(-1, 3, "Nhà phố liền kề")
    ];
  }

  static List<KeyValue> getDataPickerTrangThai() {
    return [
      new KeyValue(-1, 1, "Nháp"),
      new KeyValue(-1, 2, "Đang xử lý"),
      new KeyValue(-1, 3, "Đã duyệt"),
      new KeyValue(-1, 4, "Từ chối"),
      new KeyValue(-1, 5, "Đã xóa")
    ];
  }

  static List<KeyValue> getDataPickerDienTich() {
    return [
      new KeyValue(-1, 1, "<=30m2"),
      new KeyValue(-1, 2, "30-50m2"),
      new KeyValue(-1, 3, "50-80m2"),
      new KeyValue(-1, 3, "80-100m2"),
      new KeyValue(-1, 3, "100-150m2"),
      new KeyValue(-1, 3, "150-200m2"),
      new KeyValue(-1, 3, "200-250m2"),
      new KeyValue(-1, 3, "250-350m2"),
      new KeyValue(-1, 3, "350-500m2"),
      new KeyValue(-1, 4, ">=500m2")
    ];
  }

  static List<KeyValue> getDataPickerHuongCuaChinh() {
    return [
      new KeyValue(-1, 1, "Đông"),
      new KeyValue(-1, 2, "Tây"),
      new KeyValue(-1, 3, "Nam"),
      new KeyValue(-1, 4, "Bắc"),
      new KeyValue(-1, 5, "Đông Bắc"),
      new KeyValue(-1, 6, "Đông Nam"),
      new KeyValue(-1, 7, "Tây Bắc"),
      new KeyValue(-1, 8, "Tây Nam")
    ];
  }

  static List<KeyValue> getDataPickerGioiTinh() {
    return [
      new KeyValue(-1, 1, "Nam"),
      new KeyValue(-1, 0, "Nữ"),
      new KeyValue(-1, 2, "Khác")
    ];
  }

  static List<KeyValue> getDataPickerYesNo() {
    return [new KeyValue(-1, 1, "Có"), new KeyValue(-1, 2, "Không")];
  }

  static List<KeyValue> getDataPickerTinhTrangHonNhan() {
    return [
      new KeyValue(-1, 1, "Độc thân"),
      new KeyValue(-1, 2, "Đã có gia đình")
    ];
  }

  static List<KeyValue> getDataPickerDangBoi() {
    return [new KeyValue(-1, 1, "Cá nhân"), new KeyValue(-1, 2, "Môi giới")];
  }

  static List<KeyValue> getDataPickerLoaiTaiLieu() {
    return [
      new KeyValue(-1, 1, "Pdf"),
      new KeyValue(-1, 2, "Excel"),
      new KeyValue(-1, 3, "WebView"),
      new KeyValue(-1, 4, "Youtube")
    ];
  }

  static List<KeyValue> getDataPickerNhomKhachHang() {
    return [
      new KeyValue(-1, 1, "Bình thường"),
      new KeyValue(-1, 2, "Đã giới thiệu"),
      new KeyValue(-1, 3, "Tìm năng"),
      new KeyValue(-1, 4, "Vip")
    ];
  }

  static List<KeyValue> getDataPickerLoaiLabel() {
    return [
      new KeyValue(-1, 1, "lb"),
      new KeyValue(-1, 2, "data"),
      new KeyValue(-1, 3, "tf"),
      new KeyValue(-1, 4, "btn")
    ];
  }

  static List<KeyValue> getDataPickerTypeQuestionHelper() {
    return [new KeyValue(-1, 1, "Video"), new KeyValue(-1, 2, "Văn bản")];
  }

  static List<KeyValue> getDataPickerNgonNguGoc() {
    return [new KeyValue(-1, 1, "vi")];
  }

  static List<KeyValue> getDataPickerDapAnCauHoi() {
    return [
      new KeyValue(-1, 1, "A"),
      new KeyValue(-1, 2, "B"),
      new KeyValue(-1, 3, "C"),
      new KeyValue(-1, 4, "D")
    ];
  }

  static List<KeyValue> getDataPickerLoaiNoiDungHocOnline() {
    return [
      new KeyValue(-1, 1, "Video"),
      new KeyValue(-1, 2, "Câu hỏi trắc nghiệm")
    ];
  }

  static List<KeyValue> getDataPickerTienDoDuAn() {
    return [
      new KeyValue(-1, 1, "Đang xây dựng"),
      new KeyValue(-1, 2, "Sắp mở bán"),
      new KeyValue(-1, 3, "Đã hoàn thành")
    ];
  }

  static List<KeyValue> getDataPickerTrangThaiThamDinh() {
    return [
      new KeyValue(-1, 1, "Chưa thẩm định"),
      new KeyValue(-1, 2, "Đang thẩm định"),
      new KeyValue(-1, 3, "Đã thẩm định")
    ];
  }

  static List<KeyValue> getDataPickerTrangThaiSangNhuong() {
    return [
      new KeyValue(-1, 1, "Sang nhượng"),
      new KeyValue(-1, 2, "Cho thuê"),
      new KeyValue(-1, 3, "Bán")
    ];
  }

  static List<KeyValue> getDataPickerGiayToPhapLy() {
    return [new KeyValue(-1, 1, "Đã có sổ"), new KeyValue(-1, 2, "Chưa có sổ")];
  }

  static List<KeyValue> getDataPickerNhomThongBao() {
    return [
      new KeyValue(-1, 1, "Tài khoản"),
      new KeyValue(-1, 2, "Bất động sản"),
      new KeyValue(-1, 3, "Lời mời kết bạn")
    ];
  }

  static List<KeyValue> getDataPickerLevel() {
    return [
      new KeyValue(-1, 1, "Thành viên"),
      new KeyValue(-1, 2, "Đồng"),
      new KeyValue(-1, 3, "Bạc"),
      new KeyValue(-1, 4, "Vàng"),
      new KeyValue(-1, 5, "Bạch kim")
    ];
  }

  static List<KeyValue> getDataPickerTrangThaiHoatDong() {
    return [
      new KeyValue(-1, 1, "Đang hoạt động"),
      new KeyValue(-1, 2, "Tạm đóng cửa"),
      new KeyValue(-1, 3, "Ngưng hoạt động")
    ];
  }

  static List<KeyValue> getDataPickerDanhMucShop() {
    return [
      new KeyValue(-1, 1, "Spa"),
      new KeyValue(-1, 2, "Hair"),
      new KeyValue(-1, 3, "Nail"),
      new KeyValue(-1, 4, "Eyelash"),
      new KeyValue(-1, 5, "Makeup"),
      new KeyValue(-1, 6, "Phun xăm"),
      new KeyValue(-1, 7, "Stylish")
    ];
  }



   static List<KeyValue> getDataPicker_BDSQuocGia()
        {
            return new List<KeyValue>() {
               new KeyValue(-1,1 ,"Mỹ")
               ,new KeyValue(-1,2 ,"Úc")
              , new KeyValue(-1,3 ,"Canada")
               ,new KeyValue(-1,4 ,"Singapo")
               ,new KeyValue(-1,5 ,"Hong Kong")
               ,new KeyValue(-1,6 ,"Nhật Bản")
               ,new KeyValue(-1,7 ,"Hàn Quốc")
               ,new KeyValue(-1,8 ,"Trung Quốc")
            };
        }
}
